@@ -1,7 +1,7 @@
 import logging
 
 from django.conf.urls.defaults import url
-from adrest.views import ApiMapResource
+from adrest.views import ApiMapResource, ResourceView
 
 
 LOG = logging.getLogger('adrest')
@@ -14,35 +14,42 @@ class Api(object):
         Especially useful for navigation, HATEOAS and for providing multiple
         versions of your API.
     """
-    def __init__(self, version=None, show_map=True, **kwargs):
+    def __init__(self, version=None, show_map=True, **params):
         self.version = version
         self.show_map = show_map
-        self.kwargs = kwargs
+        self.params = params
+        self._map = dict()
+
         try:
             self.str_version = '.'.join(map(str, version or list()))
         except TypeError:
             self.str_version = str(version)
 
-        self._map = dict()
+    def register(self, resource, urlregex=None, urlname=None, **params):
+        " Register resource subclass with API "
+
+        assert issubclass(resource, ResourceView), " Resource must have ResourceView type "
 
-    def register(self, resource, urlregex=None, urlname=None, **kwargs):
-        """ Register resource subclass with API.
-        """
         urlname = urlname or resource.meta.urlname
         urlregex = urlregex or resource.meta.urlregex
 
-        if self._map.get(urlname):
+        if self._map.get(resource.meta.urlname):
             LOG.warning("A new resource '%r' is replacing the existing record for '%s'" % (resource, urlname))
 
-        params = dict(**self.kwargs)
-        params.update(kwargs)
-        self._map[urlname] = dict(resource=resource, urlregex=urlregex, urlname=urlname, params=params)
+        # Resource fabric
+        params = dict(self.params, **params)
+        if params:
+            params['name'] = ''.join(bit for bit in resource.__name__.split('Resource') if bit).lower()
+            resource = type('%s%s' % (resource.__name__, len(self._map)), (resource,), params)
+
+        self._map[urlname] = urlregex, resource
 
     @property
     def urls(self):
         """ Provides URLconf details for the ``Api`` and all registered
             ``Resources`` beneath it.
         """
+
         patterns = []
         url_vprefix = name_vprefix = ''
 
@@ -56,25 +63,13 @@ class Api(object):
                 url(r"^%s$" % url_vprefix, ApiMapResource.as_view(api=self), name="api-%s%s" % (name_vprefix, ApiMapResource.meta.urlname)),
             )
 
-        part = 0
         for urlname in sorted(self._map.keys()):
 
-            info = self._map[urlname]
+            urlregex, resource = self._map[urlname]
 
-            # Resource
-            resource = info['resource']
-
-            # URL
-            urlname = 'api-%s%s' % ( name_vprefix, urlname)
-            urlregex = '^%s%s' % ( url_vprefix, info['urlregex'])
-
-            params = info.get('params')
-            if params:
-                part += 1
-                params['name'] = ''.join(bit for bit in resource.__name__.split('Resource') if bit).lower()
-                resource = type('%s%s' % (resource.__name__, part), (resource,), params)
-            view = resource.as_view(api=self)
-            patterns.append(url(urlregex, view, name=urlname))
+            patterns.append(url('^%s%s' % (url_vprefix, urlregex),
+                        resource.as_view(api=self),
+                        name='api-%s%s' % (name_vprefix, urlname)))
 
         return patterns
 
